#!/bin/bash
# (C) Klaus Knopper Nov 2002
# Recreate desktop icons for CD-Roms and harddisks in KDE and GNOME
# This script must be run as the logged in user.

scan=""
verbose=""
for i in "$@"; do
case "$i" in
-s*) scan="true" ;; 
-v*) verbose="-v" ;;
*)  echo "Usage: $0 -s[can] -v[erbose]" >&2 ;;
esac
done

# rebuildfstab requires root privileges, calls su if necessary
[ -n "$scan" ] && rebuildfstab -r $verbose 

if [ "`id -u`" = "0" ]; then
 # Script has been called as root, re-execute to create desktop icons for all users!
 # KNOPPIX: Add KDE/GNOME icons for new harddisks
 for d in $(ls -1d /home/*/Desktop); do
  if [ -d "$d" ]; then
   user="${d%/Desktop}"
   user="${user#/home/}"
   if [ "$user" != "root" ]; then
    HOME="/home/$user" sudo -H -u "$user" "$0" >/dev/null 2>&1
   fi
  fi
 done
 exit 0
fi

# GNOME's nautilus 2 does not know how to handle icons of Type=FSDevice yet,
# so exit if the _only_ session on this computer is currently a gnome-session,
# and no KDE is running.
# This is a terrible workaround.

PSAX="$(ps ax)"
case "$PSAX" in *nautilus*) case "$PSAX" in *\ kwin*) ;; *) exit 0 ;; esac ;; esac

# KDE desktop
if [ ! -d $HOME/Desktop ]; then
 mkdir -p $HOME/Desktop
else
 rm -f $HOME/Desktop/cdrom?* $HOME/Desktop/[hs]d[a-z]* $HOME/Desktop/ub[a-z]* 2>/dev/null
fi

# GNOME desktop 
# .gnome-desktop is obsolete, uses same Desktop directory as KDE now.

# Old CD-Rom Entry for Knoppix 4.x.
# We now let HAL/KDE do Floppies and CD-Roms.
#[Desktop Entry]
#MountPoint=/media/$d
#Actions=DVD;Music;Burn;Eject
#Name=CD-ROM [$d]
#UnmountIcon=cdrom_unmount
#Icon=cdrom_mount
#Type=FSDevice
#Dev=$i
#MountPoint=/media/$d
#Comment=File System Device
#Comment[pl]=Urzdzenie
#Comment[pt]=Dispositivo com Sistema de Ficheiros
#Comment[fi]=Tiedostosysteemi
#Comment[fr]=Priphrique avec systme de fichiers
#Comment[it]=Dispositivo con  Sistema File
#Comment[de]=Dateisystem
#X-KDE-Priority=TopLevel
#
#[Desktop Action Eject]
#Icon=player_eject
#Exec=kdeeject %v;true
#Name=Eject
#Name[de]=Auswerfen
#Dev=$i
#MountPoint=/media/$d
#
#[Desktop Action DVD]
#Icon=video
#Exec=playvideodisk xine $i;true
#Name=DVD/VCD-Player
#Name[de]=DVD/Video-CD abspielen
#Dev=$i
#MountPoint=/media/$d
#
#[Desktop Action Burn]
#Icon=k3b
#Exec=k3b %i %m -caption "%c";true
#Name=Create CD/CDRW
#Name[de]=CD-R/RW brennen
#Dev=$i
#MountPoint=/media/$d
#
#[Desktop Action Music]
#Icon=xmms
#Exec=xmms $i;true
#Name=Play Music CD
#Name[de]=Musik-CD abspielen
#Dev=$i
#MountPoint=/media/$d
#ENDCD
#

# HD partitions (except swap)
while read p m t relax; do
 case "$t" in swap) continue ;; esac
 # Skip Floppy and CD-Rom entries that are already there
 case "$p$m" in *floppy*|*fd0*|*cdrom*) continue ;; esac
 case "$m" in /media/*|/mnt/*)
  d="${p##*/}"
  # Ignore USB/IDE CD-Roms (handled by HAL)
  group="$(stat --format="%G" "$p" 2>/dev/null)"
  [ "$group" = "cdrom" ] && continue
  icon="hdd"
  # udev uses group "floppy" for new usb pendrives now.
  [ "$group" = "floppy" ] && icon="usbpendrive"
  cat >$HOME/Desktop/"$d" <<ENDHD
[Desktop Entry]
Actions=Remount
Type=FSDevice
Dev=$p
MountPoint=$m
FSType=auto
ReadOnly=true
Icon=${icon}_mount
UnmountIcon=${icon}_unmount
Name=Hard Disk [$d]
Name[de]=Festplatte [$d]
Name[at]=Festplatte [$d]
Name[ch]=Festplatte [$d]
Name[nl]=Harde Schijf [$d]
Name[es]=Disco duro [$d]
X-KDE-Priority=TopLevel
X-KDE-Dynamic-Device=true

[Desktop Action Remount]
Icon=hdd_mount
Exec=remountrw $p;true
Name=Change read/write mode
Name[nl]=Lezen/Schrijven toepassen
Name[de]=Lese-/Schreibmodus ndern
Name[es]=Cambiar modo lectura/escritura
ENDHD
  ;;
 esac
done </etc/fstab
exit 0
